package com.example.admin.mydatabaseapp;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.util.Log;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

/**Class to facilitate data manipulation.*/
public class DBHelper {
    // Database fields
    private SQLiteDatabase database;
    private MySQLiteHelper SQLHelper;
    private String[] allColumns = { MySQLiteHelper.COLUMN_ID,
            MySQLiteHelper.COLUMN_NAME };

    private static final String TAG = "DBDEMO";

    public DBHelper(Context context) {
        SQLHelper = new MySQLiteHelper(context);
    }

    public void open() throws SQLException {
        database = SQLHelper.getWritableDatabase();
    }

    public void close() {
        SQLHelper.close();
    }


    public Person createPerson(String name) {
        ContentValues values = new ContentValues();
        values.put(MySQLiteHelper.COLUMN_NAME, name);
        long insertId = database.insert(MySQLiteHelper.TABLE_NAME, null,
                values);
        Cursor cursor = database.query(MySQLiteHelper.TABLE_NAME,
                allColumns, MySQLiteHelper.COLUMN_ID + " = " + insertId, null,
                null, null, null);
        cursor.moveToFirst();
        Person newPerson = cursorToPerson(cursor);

        // Log the comment stored
        Log.d(TAG, "comment = " + cursorToPerson(cursor).toString()
                + " insert ID = " + insertId);

        cursor.close();
        return newPerson;
    }

    public void deletePerson(Person person) {
        long id = person.getId();
        Log.d(TAG, "delete comment = " + id);
        System.out.println("Person deleted with id: " + id);
        database.delete(MySQLiteHelper.TABLE_NAME, MySQLiteHelper.COLUMN_ID
                + " = " + id, null);
    }

    public void deleteAllPersons() {
        System.out.println("All persons deleted all");
        Log.d(TAG, "delete all = ");
        database.delete(MySQLiteHelper.TABLE_NAME, null, null);
    }


    public List<Person> getAllComments() {
        List<Person> persons = new ArrayList<Person>();

        Cursor cursor = database.query(MySQLiteHelper.TABLE_NAME,
                allColumns, null, null, null, null, null);

        cursor.moveToFirst();
        while (!cursor.isAfterLast()) {
            Person person = cursorToPerson(cursor);
            Log.d(TAG, "get comment = " + cursorToPerson(cursor).toString());
            persons.add(person);
            cursor.moveToNext();
        }
        // Make sure to close the cursor
        cursor.close();
        return persons;
    }

    private Person cursorToPerson(Cursor cursor) {
        Person person = new Person();
        person.setId(cursor.getLong(0));
        person.setName(cursor.getString(1));
        return person;
    }
}
